@@ -98,29 +98,35 @@ set_confirm_value(char * buf, size_t bsz, unsigned char * data, size_t d_len,
 {
     const int buf_off = CONFIRM_LEN + 1;
     assert(bsz > (buf_off * 2));
-    base64_encode((char *)data, d_len, buf, buf_off);
-    buf[buf_off - 1] = buf[buf_off] = ' ';
 
-    {
+    /*
+     * The user wants the old style, changeable confirmation answer.
+     * It has already been computed in "data".
+     */
+    if (! HAVE_OPT(OLD_CONFIRM)) {
         union {
             uintptr_t       data[256 / (NBBY * sizeof(uintptr_t))];
             unsigned char   sha_buf[256 / NBBY];
         } sum;
 
         struct sha256_ctx ctx;
-        sha256_init_ctx(&ctx);
 
+	/*
+	 * compute a new hash based only on the password id string and
+	 * the confirmation text
+	 */
+        sha256_init_ctx(&ctx);
         sha256_process_bytes(pwd_id_str, strlen(pwd_id_str)+1, &ctx);
         sha256_process_bytes(OPT_ARG(CONFIRM), strlen(OPT_ARG(CONFIRM))+1, &ctx);
         sha256_finish_ctx(&ctx, sum.sha_buf);
 
-        base64_encode((char *)sum.sha_buf, sizeof(sum.sha_buf),
-                      buf + buf_off+1, bsz - buf_off - 1);
+	data   = (unsigned char *)sum.sha_buf;
+	d_len  = sizeof(sum.sha_buf);
     }
 
-    buf[buf_off + CONFIRM_LEN + 1] = NUL;
+    base64_encode((char *)data, d_len, buf, buf_off);
+    buf[CONFIRM_LEN] = NUL;
     fix_lower_only_pw(buf);
-    buf[buf_off - 1] = buf[buf_off] = ' ';
 }
 
 /**
@@ -212,8 +218,8 @@ get_dft_pw(char * buf, size_t bsz,
  * @param nam   the password id
  */
 static void
-get_pbkdf2_pw(char * buf, size_t bsz,
-              char const * tag, char const * salt, char const * pwd_id_str)
+get_rehashed_pw(char * buf, size_t bsz,
+                char const * tag, char const * salt, char const * pwd_id_str)
 {
     size_t const stag_len = strlen(tag) + 1;  // seed tag len
     size_t const salt_len = strlen(salt) + 1; // salt length
@@ -273,7 +279,7 @@ print_pwid_status(char const * pwd_id_str)
     if (HAVE_OPT(LOGIN_ID)) {
         have_data = true;
         print_pwid_header(pwd_id_str);
-        printf(pwst_str_fmt, "login-id", OPT_ARG(LOGIN_ID));
+        printf(pwst_str_fmt, DESC(LOGIN_ID).pz_Name, OPT_ARG(LOGIN_ID));
     }
 
     if (HAVE_OPT(LENGTH)) {
@@ -281,7 +287,7 @@ print_pwid_status(char const * pwd_id_str)
             print_pwid_header(pwd_id_str);
             have_data = true;
         }
-        printf(pwst_dig_fmt, "length", (unsigned int)OPT_VALUE_LENGTH);
+        printf(pwst_dig_fmt, DESC(LENGTH).pz_Name, (unsigned int)OPT_VALUE_LENGTH);
     }
 
     if (HAVE_OPT(PBKDF2) || (OPT_VALUE_LENGTH > (MIN_BUF_LEN - 8))) {
@@ -290,9 +296,9 @@ print_pwid_status(char const * pwd_id_str)
             have_data = true;
         }
         if (ENABLED_OPT(PBKDF2) || (OPT_VALUE_LENGTH > (MIN_BUF_LEN - 8)))
-            printf(pwst_dig_fmt, "pbkdf2 ct", (unsigned int)OPT_VALUE_PBKDF2);
+            printf(pwst_dig_fmt, "rehash ct", (unsigned int)OPT_VALUE_PBKDF2);
         else
-            printf(pwst_str_fmt, "pbkdf2", "not used");
+            printf(pwst_str_fmt, DESC(REHASH).pz_Name, "not used");
     }
 
     if (HAVE_OPT(SPECIALS)) {
@@ -300,7 +306,7 @@ print_pwid_status(char const * pwd_id_str)
             print_pwid_header(pwd_id_str);
             have_data = true;
         }
-        printf(pwst_str_fmt, "spec chars", OPT_ARG(SPECIALS));
+        printf(pwst_str_fmt, DESC(SPECIALS).pz_Name, OPT_ARG(SPECIALS));
     }
 
     if (HAVE_OPT(CCLASS)) {
@@ -312,14 +318,14 @@ print_pwid_status(char const * pwd_id_str)
         }
         doOptCclass(OPTPROC_RETURN_VALNAME, &DESC(CCLASS));
         names = DESC(CCLASS).optArg.argString;
-        printf(pwst_str_fmt, "ch-class", names);
+        printf(pwst_str_fmt, DESC(CCLASS).pz_Name, names);
         free((void *)names);
     }
 
     if (! have_data)
-        printf("The %s password id has all default settings\n", pwd_id_str);
+        printf(default_all_fmt, pwd_id_str);
     else if (! HAVE_OPT(PBKDF2))
-        printf(pwst_dig_dft, "pbkdf2 ct", (unsigned int)OPT_VALUE_PBKDF2);
+        printf(pwst_dig_dft, DESC(REHASH).pz_Name, (unsigned int)OPT_VALUE_PBKDF2);
 }
 
 /**
@@ -373,7 +379,7 @@ print_one_pwid(tOptionValue const * seed_opt, char const * pwd_id_str)
 
         if ((ver == NULL) || (ver->valType != OPARG_TYPE_NUMERIC)) {
             tOptionValue const * tag = optionGetValue(seed_opt, tag_z);
-            warning_msg(too_old_z, tag->v.strVal);
+            warning_msg(too_old_fmt, tag->v.strVal);
             return false;
         }
     }
@@ -420,8 +426,8 @@ print_one_pwid(tOptionValue const * seed_opt, char const * pwd_id_str)
                    tag->v.strVal, txt->v.strVal, pwd_id_str);
 
     else
-        get_pbkdf2_pw((char *)txtbuf, buf_len,
-                      tag->v.strVal, txt->v.strVal, pwd_id_str);
+        get_rehashed_pw((char *)txtbuf, buf_len,
+			tag->v.strVal, txt->v.strVal, pwd_id_str);
 
     if (HAVE_OPT(SELECT_CHARS))
         select_chars(txtbuf);
@@ -442,6 +448,7 @@ print_pwid(char const * pwd_id_str)
     if (*pwd_id_str == NUL)
         die(GNU_PW_MGR_EXIT_NO_PWID, no_pwid);
 
+    load_config_file();
     set_pwid_opts(pwd_id_str);
     if (HAVE_OPT(STATUS)) {
         print_pwid_status(pwd_id_str);
@@ -457,12 +464,12 @@ print_pwid(char const * pwd_id_str)
     if (! HAVE_OPT(NO_HEADER)) {
         char const * hdr_type = hdr_normal;
         if (HAVE_OPT(CONFIRM)) {
-            pbkdf2_date="";
-            hdr_type = hdr_confirm;
+            rehash_date = "";
+            hdr_type    = hdr_confirm;
         }
         if (HAVE_OPT(LOGIN_ID))
             printf(hdr_hint, OPT_ARG(LOGIN_ID));
-        printf(pw_hdr_fmt, hdr_type, pbkdf2_date);
+        printf(pw_hdr_fmt, hdr_type, rehash_date);
     }
 
     /*
@@ -477,7 +484,8 @@ print_pwid(char const * pwd_id_str)
         die(GNU_PW_MGR_EXIT_NO_SEED, no_passwords,
             ENABLED_OPT(SHARED) ? sec_pw_type : "");
 
-    update_pwid_opts(pwd_id_str);
+    if (update_stored_opts)
+        update_pwid_opts(pwd_id_str);
 }
 
 /**
@@ -725,12 +733,13 @@ main(int argc, char ** argv)
         proc_dom_opts(argc);
 
     /*
-     * There are four operational modes:
+     * There are five operational modes:
      *
      * 1) command line operands signify printing a password, otherwise
      * 2) not having a --tag option says to read a password id from stdin, else
      * 3) not having --text option says to remove a seed, else
      * 4) add a new password seed using --tag and --text
+     * 5) change the character class defaults.
      */
     if (argc > 0) {
         char const * arg;
@@ -748,6 +757,9 @@ main(int argc, char ** argv)
 
         print_pwid(arg);
 
+    } else if (HAVE_OPT(DEFAULT_CCLASS)) {
+	set_default_cclass();
+
     } else if (! HAVE_OPT(TAG)) {
 
         /*
@@ -762,14 +774,21 @@ main(int argc, char ** argv)
             usage_message(disable_second);
         add_seed();
 
-    } else {
-        if (HAVE_OPT(SHARED))
-            usage_message(shared_removal);
-        rm_seed();
-    }
+    } else if (HAVE_OPT(SHARED))
+	usage_message(shared_removal);
+
+    else rm_seed();
 
     secure_cfg_file();
 
     scribble_deinit();
     return GNU_PW_MGR_EXIT_SUCCESS;
 }
+
+/*
+ * Local Variables:
+ * mode: C
+ * c-file-style: "stroustrup"
+ * indent-tabs-mode: nil
+ * End:
+ * end of gnu-pw-mgr.c */
